==> methylumi_1.0.0.zip: methylumi/doc/methylumi.R <==
###################################################
### chunk number 1: init
###################################################
options(width=50)
library(lattice)
library(xtable)


###################################################
### chunk number 2: 
###################################################
library(methylumi)
samps <- read.table(system.file("extdata/samples.txt",
                                package = "methylumi"),sep="\t",header=TRUE)
mldat <- methylumiR(system.file('extdata/exampledata.samples.txt',package='methylumi'),
                    qcfile=system.file('extdata/exampledata.controls.txt',package="methylumi"),
                    sampleDescriptions=samps)


###################################################
### chunk number 3: 
###################################################
mldat


###################################################
### chunk number 4: 
###################################################
getAssayDataNameSubstitutions()


###################################################
### chunk number 5: 
###################################################
md <- cmdscale(dist(t(exprs(mldat)[fData(mldat)$CHROMOSOME=='X',])),2)


###################################################
### chunk number 6: 
###################################################
plot(md,pch=c('F','M')[pData(mldat)$Gender],col=c('red','blue')[pData(mldat)$Gender])


###################################################
### chunk number 7: 
###################################################
avgPval <- colMeans(pvals(mldat))
par(las=2)
barplot(avgPval,ylab="Average P-Value")


###################################################
### chunk number 8: 
###################################################
controlTypes(mldat)


###################################################
### chunk number 9: 
###################################################
qcplot(mldat,"FIRST HYBRIDIZATION")


###################################################
### chunk number 10: 
###################################################
toKeep <- (avgPval<0.05)
pData(mldat)$Gender[9] <- "F"
mldat.norm <- normalizeMethyLumiSet(mldat[,toKeep])


###################################################
### chunk number 11: 
###################################################
library(limma)
dm <- model.matrix(~1+Gender,data=pData(mldat.norm))
colnames(dm)
fit1 <- lmFit(exprs(mldat.norm),dm)
fit2 <- eBayes(fit1)
tt <- topTable(fit2,coef=2,genelist=fData(mldat.norm)[,c('SYMBOL','CHROMOSOME')],number=1536)
x <- aggregate(tt$adj.P.Val,by=list(tt$CHROMOSOME),median)
colnames(x) <- c('Chromosome','Median adjusted P-value')


###################################################
### chunk number 12: 
###################################################
library(xtable)
xt <- xtable(x,label="tab:chromosomepvals",caption="The median adjusted p-value for each chromosome showing that the X-chromosome is highly significantly different between males and females")
digits(xt) <- 6
print(xt,include.rownames=FALSE,align="cr")


###################################################
### chunk number 13: 
###################################################
pdf('gender_probes_by_chrom.pdf')
print(xyplot(-log10(adj.P.Val)~CHROMOSOME,
       tt,ylab="-log10(Adjusted P-value)",
       main="P-values for probes\ndistinguising males from females"))
invisible(dev.off())


###################################################
### chunk number 14: 
###################################################
toLatex(sessionInfo())

==> methylumi_1.6.1.zip: methylumi/doc/methylumi.R <==
###################################################
### chunk number 1: init
###################################################
#line 30 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
options(width=50)
library(lattice)
library(xtable)


###################################################
### chunk number 2: 
###################################################
#line 52 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
library(methylumi)
samps <- read.table(system.file("extdata/samples.txt",
                                package = "methylumi"),sep="\t",header=TRUE)
mldat <- methylumiR(system.file('extdata/exampledata.samples.txt',package='methylumi'),
                    qcfile=system.file('extdata/exampledata.controls.txt',package="methylumi"),
                    sampleDescriptions=samps)


###################################################
### chunk number 3: 
###################################################
#line 62 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
mldat


###################################################
### chunk number 4: 
###################################################
#line 70 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
getAssayDataNameSubstitutions()


###################################################
### chunk number 5: 
###################################################
#line 78 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
md <- cmdscale(dist(t(exprs(mldat)[fData(mldat)$CHROMOSOME=='X',])),2)


###################################################
### chunk number 6: 
###################################################
#line 82 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
plot(md,pch=c('F','M')[pData(mldat)$Gender],col=c('red','blue')[pData(mldat)$Gender])


###################################################
### chunk number 7: 
###################################################
#line 88 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
avgPval <- colMeans(pvals(mldat))
par(las=2)
barplot(avgPval,ylab="Average P-Value")


###################################################
### chunk number 8: 
###################################################
#line 98 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
controlTypes(mldat)


###################################################
### chunk number 9: 
###################################################
#line 104 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
qcplot(mldat,"FIRST HYBRIDIZATION")


###################################################
### chunk number 10: 
###################################################
#line 116 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
toKeep <- (avgPval<0.05)
pData(mldat)$Gender[9] <- "F"
mldat.norm <- normalizeMethyLumiSet(mldat[,toKeep])


###################################################
### chunk number 11: 
###################################################
#line 126 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
library(limma)
dm <- model.matrix(~1+Gender,data=pData(mldat.norm))
colnames(dm)
fit1 <- lmFit(exprs(mldat.norm),dm)
fit2 <- eBayes(fit1)
tt <- topTable(fit2,coef=2,genelist=fData(mldat.norm)[,c('SYMBOL','CHROMOSOME')],number=1536)
x <- aggregate(tt$adj.P.Val,by=list(tt$CHROMOSOME),median)
colnames(x) <- c('Chromosome','Median adjusted P-value')


###################################################
### chunk number 12: 
###################################################
#line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
library(xtable)
xt <- xtable(x,label="tab:chromosomepvals",caption="The median adjusted p-value for each chromosome showing that the X-chromosome is highly significantly different between males and females")
digits(xt) <- 6
print(xt,include.rownames=FALSE,align="cr")


###################################################
### chunk number 13: 
###################################################
#line 146 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
pdf('gender_probes_by_chrom.pdf')
print(xyplot(-log10(adj.P.Val)~CHROMOSOME,
       tt,ylab="-log10(Adjusted P-value)",
       main="P-values for probes\ndistinguising males from females"))
invisible(dev.off())


###################################################
### chunk number 14: 
###################################################
#line 163 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpV2htNI/R.INSTALLf623520/methylumi/inst/doc/methylumi.Rnw"
toLatex(sessionInfo())
